# pysqlizer - SQL Query Generator
# Copyright (c) 2025 Akash Kushwaha
# Licensed under the MIT License. See LICENSE file for details.

import sys

def sqlify(keyColumn, data, how='', condition='=', raiseException=True):
    """Dynamically generates SQL conditions."""
    try:
        if not isinstance(keyColumn, str) or not keyColumn.strip():
            raise ValueError("keyColumn must be a non-empty string.")
        if not isinstance(raiseException, bool):
            raise ValueError("raiseException must be a boolean.")
        
        if isinstance(data, (int, str)):
            data = (data,)
        elif isinstance(data, (list, set, tuple)):
            data = tuple(data)
        elif isinstance(data, dict):
            data = tuple(data.keys())

        if not data:
            return ''

        condition_type = how.upper().strip() if how else ''
        if len(data) == 1:
            value = f"'{data[0]}'" if isinstance(data[0], str) else data[0]
            return f"{condition_type} {keyColumn} {condition} {value}".strip()
        else:
            formatted_values = ', '.join(f"'{v}'" if isinstance(v, str) else str(v) for v in data)
            return f"{condition_type} {keyColumn} IN ({formatted_values})".strip()

    except Exception as e:
        return '' if not raiseException else sys.exit(1)

def sqlifylike(keyColumn, data, wildcard="%{value}%"):
    """Generates SQL LIKE conditions dynamically."""
    try:
        if not isinstance(data, str) or not data.strip():
            return ''

        formatted_value = wildcard.replace("{value}", data)
        return f"{keyColumn} LIKE '{formatted_value}'"

    except Exception as e:
        return ''
